Skip to contents

Prints summary of wmwAUC test results.

Usage

# S3 method for class 'wmwAUC_test'
print(x, digits = 3, ...)

Arguments

x

Object of class 'wmwAUC_test' returned by wmwAUC_test()

digits

Integer, number of digits to display for numeric results (default: 3)

...

Additional arguments (not currently used)

Value

Invisibly returns the input object x (of class "wmwAUC_test"). Called primarily for side effects to print a formatted summary of the wmwAUC test results to the console.