Learn R Programming

wmwAUC (version 0.2.0)

print.wmw_test: Print Method for wmw_test Objects

Description

Prints summary of Wilcoxon-Mann-Whitney discrimination test results.

Usage

# S3 method for wmw_test
print(x, digits = 3, ...)

Value

Invisibly returns the input object x (of class "wmw_test"). Called primarily for side effects to print a formatted summary of the Wilcoxon-Mann-Whitney test results to the console.

Arguments

x

Object of class 'wmw_test' returned by wmw_test()

digits

Integer, number of digits to display for numeric results (default: 4)

...

Additional arguments (not currently used)