Learn R Programming

wmwAUC (version 0.2.0)

test_shift_equivalence: Test of equality of distributions from twosamples library applied to median-centered data

Description

Applies a specified test from twosamples library to median-centered data.

Usage

test_shift_equivalence(x, y, test = "ks", seed = 123L)

Value

A list of class "shift_test" containing:

statistic

Test statistic value

p.value

P-value of the shift equivalence test

method

Character string describing the test method

alternative

Character string describing the alternative hypothesis

data.name

Character string with the names of the data

assumptions_met

Logical indicating if shift equivalence assumptions are satisfied

Arguments

x

vector

y

vector

test

one of c("ks", "kuiper", "cvm", "ad", "wass", "dts")

seed

numeric, used in set.seed()

References

For more details see the Two Sample Test Package Website

Dowd, C. (2020). A new ECDF two-sample test statistic. arXiv preprint arXiv:2007.01360.