Prints summary of Wilcoxon-Mann-Whitney discrimination test results.
# S3 method for wmw_test
print(x, digits = 3, ...)Invisibly returns the input object x (of class "wmw_test").
Called primarily for side effects to print a formatted summary
of the Wilcoxon-Mann-Whitney test results to the console.
Object of class 'wmw_test' returned by wmw_test()
Integer, number of digits to display for numeric results (default: 4)
Additional arguments (not currently used)