ROC related computations -- internal function
roc_with_ci(
probs,
labels,
positive,
auc,
ci_method = c("none", "hanley", "bootstrap"),
n_boot = 1000,
alpha = 0.05
)List with components:
data frame for plotting ROC curve
data frame for plotting confidence band of ROC
auc
confint for auc
Vector of class probabilities or values of continuous predictor
Vector, factor with two levels
Character giving the level that corresponds to 'case'
Numeric value of AUC
Character from c("none", "hanley", "bootstrap")
Numeric value giving the number of bootstrap replicates (default: 1000)
Level of significance (default: 0.05)