Applies a specified test from twosamples library to median-centered data.
test_shift_equivalence(x, y, test = "ks", seed = 123L)A list of class "shift_test" containing:
Test statistic value
P-value of the shift equivalence test
Character string describing the test method
Character string describing the alternative hypothesis
Character string with the names of the data
Logical indicating if shift equivalence assumptions are satisfied
vector
vector
one of c("ks", "kuiper", "cvm", "ad", "wass", "dts")
numeric, used in set.seed()
For more details see the Two Sample Test Package Website
Dowd, C. (2020). A new ECDF two-sample test statistic. arXiv preprint arXiv:2007.01360.