These functions have been renamed in wmwAUC 1.0.0, alongside argument and behavior changes in some cases. Calling them raises an informative error pointing to the current function and to NEWS.md, rather than attempting to forward the call – for functions with argument-name or argument-value changes (see Details), a silent passthrough could otherwise produce a different result than the old function used to, without any indication that anything had changed.
Details
wmw_test()->wmwAUC_test. Thespecial_caseargument was renamedpseudomedian, and theci_method = 'hanley'option was removed (not renamed), and replaced by the DeLong et al. (1988) method.wmw_pvalue()->wmwAUC_pvalue_BC.wmw_pvalue_ties()->wmwAUC_pvalue_EU.pseudomedian_ci()->wmwAUC_pseudomedian_ci.